//----------------------------------------------------------------------------
// 
//	file: spikelayer2
// 
//	function: make spikelayer more robust to parameter change 
//	author:   Yoonsuck Choe <yschoe@cs.utexas.edu>
//	creation: Fri Nov 27 04:49:20 CST 1998
// 
//	$Revision: 1.3 $ $Date: 2001/11/30 20:24:15 $
//	$Log: spikelayer2.h,v $
//	Revision 1.3  2001/11/30 20:24:15  yschoe
//	pglissom v1.0 release
//
//	Revision 1.2  2000/02/08 11:25:21  yschoe
//	*** empty log message ***
//
//	Revision 1.1  1999/02/09 07:42:25  yschoe
//	Initial revision
//
//
//----------------------------------------------------------------------------
#ifndef __SPIKE_LAYER2_H
#define __SPIKE_LAYER2_H

#include "spikelayer.h"

//----------------------------------------------------------------------------
//	CLASS spikelayer
//	  - spiking lissom layer - derived from netlayer
//----------------------------------------------------------------------------
class spikelayer2 : public spikelayer{

  // General idea:
  //	Put decayed spike activity in this->output[x][y], so that
  //	it could be generically used with other types of netlayers.
  //	No spikes actually goes through the connection this way.
  //	Thus the postsynaptic potential is calculated for all 
  //	targets receiving from a certain neuron.

private:

	REAL synapse_decay_mult;

public:
	REAL min_net_input, max_net_input;

	spikelayer2(char *name, int cols, int rows, int exc_rad, int inh_rad,
                 int max_inp_layers, netlayer *feeding,
                 int inp_cols, int inp_rows, int  aff_rad, 
		 REAL synapse_decay, REAL inhloop_decay, 
		 REAL theta=0.0, REAL tau=0.0,
		 int padded_flag=1);
       ~spikelayer2();

	void activate(int calc_aff = 0);
	void calc_spike();
	void calc_spike_accumulate();
	void print_stat(int i, int j);
	void print_stat(int cur_inp, int i, int j);
	void kill_recursive_lat();

};

#endif
