//----------------------------------------------------------------------------
// 
//	file: correl.c
// 
//	function: calculate auto and cross correlation of time series 
//	author:   Yoonsuck Choe <yschoe@cs.utexas.edu>
//	creation: Fri Nov  6 03:50:40 CST 1998
// 
//	$Revision: 1.1 $ $Date: 1999/02/09 07:56:44 $
//	$Log: autocorrel.cc,v $
//	Revision 1.1  1999/02/09 07:56:44  yschoe
//	Initial revision
//
//
//----------------------------------------------------------------------------
#include <iostream.h>
#include <math.h>
#include <stdlib.h>
#include "../real.h"


//----------------------------------------------------------------------------
//	autocorrel() 
//	  - return auto correlation of timeseries and return r_k in dest.
//----------------------------------------------------------------------------
REAL autocorrel(REAL *dest, REAL *series, int size) {

  // calculate mean
  REAL sum = 0.0;
  for (int i=0; i<size; ++i) {
	sum += series[i];
  }
  REAL mean = sum/(REAL)size;

  // calculate Sum((x_t-mean)^2) : commonly used for all r_k
  REAL sumsqr = 0.0;
  for (int i=0; i<size; ++i) {
	sumsqr += (series[i]-mean)*(series[i]-mean);
  }

  // calculate r_k 
  for (int k=0; k<size; ++k) {
     dest[k] = 0.0;
     for (int t=0; t<size-k; ++t) {
	dest[k] += (series[t]-mean)*(series[t+k]-mean)/sumsqr;
     }
  }

}


//----------------------------------------------------------------------------
//	main() 
//----------------------------------------------------------------------------
int main (int argc, char *argv[]) {

  REAL *series;
  REAL *correl;

  if (argc!=3) {
     cout << "usage: correl <samples> < inputfile" << endl;
     exit(0);
  }

  int  size = atoi(argv[1]);

  series = new REAL [size];
  correl = new REAL [size];

  for (int i=0; i<size; ++i) {
	fscanf(stdin,"%f",&series[i]);
  }

  autocorrel(correl,series,size);

  for (int i=0; i<size; ++i) {
     cout << i << " " << correl[i] << " " << series[i] << endl;
  }

}  
